import SwiftUI

extension Collection {
    // Support collection[safe: number]
    subscript (safe index: Index) -> Element? {
        return indices.contains(index) ? self[index] : nil
    }
   
    // Support collection[safe: number, default: "some default value"]
    subscript (safe index: Index, default value: Element) -> Element {
        return indices.contains(index) ? self[index] : value
    }
}

struct ContentView: View {
    let pokemon = [
        "Pikachu", // 0
        "Lugia", // 1
        "Dragonite", // 2
        "Mewtwo" // 3
    ]

    var body: some View {
        VStack {
            Text("This example is code-only")
        }
        .task {
            // This will crash 💥 if enabled
            // print(pokemon[10]) 

            // This returns nil
            print(pokemon[safe: 10])
            
            // This returns "Pikachu"
            print(pokemon[safe: 10, default: "Pikachu"])
        }
    }
}
